Crate mathtex_editor_keymap

Crate mathtex_editor_keymap 

The default Hypatia keymap maps host input to primitive Commands.

Structs

KeyInput
A normalized key event from the host matching browser KeyboardEvent fields.
Keymap
Input state for character autocorrect, word autoconvert, and host word shortcuts.
KeymapEntry
A popover row with a trigger word and display label.