pub struct Keymap { /* private fields */ }Expand description
Input state for character autocorrect, word autoconvert, and host word shortcuts.
Implementations
Sourceimpl Keymap
impl Keymap
Sourcepub fn define_word(&mut self, word: impl Into<String>, commands: Vec<Command>)
pub fn define_word(&mut self, word: impl Into<String>, commands: Vec<Command>)
Register a user word shortcut so word plus space expands to commands.
Sourcepub fn undefine_word(&mut self, word: &str)
pub fn undefine_word(&mut self, word: &str)
Remove a previously registered word shortcut while leaving built ins unaffected.
Sourcepub fn entries(&self) -> Vec<KeymapEntry<'_>>
pub fn entries(&self) -> Vec<KeymapEntry<'_>>
Return words the keymap can expand for a \ command popover.
Sourcepub fn map_key(&mut self, input: &KeyInput) -> Vec<Command>
pub fn map_key(&mut self, input: &KeyInput) -> Vec<Command>
Translate a key event into zero or more editor commands.